@@ -446,20 +446,20 @@ if isnotebook():
 package_files = {}
 
 
-# In[50]:
+# In[59]:
 
 
 package_files['setup.py'] = r"""from distutils.core import setup
 setup(
   name = 'lx',         # How you named your package folder (MyLib)
   packages = ['lx'],   # Chose the same as "name"
-  version = '0.18',      # Start with a small number and increase it with every change you make
+  version = '0.19',      # Start with a small number and increase it with every change you make
   license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
   description = 'lx',   # Give a short description about your library
   author = 'lx',                   # Type in your name
   author_email = 'hx2983113@gmail.com',      # Type in your E-Mail
   #url = 'https://github.com/hx2983113/lx',   # Provide either the link to your github or to your website
-  #download_url = 'https://github.com/hx2983113/lx/archive/0.18.tar.gz',    # I explain this later on
+  #download_url = 'https://github.com/hx2983113/lx/archive/0.19.tar.gz',    # I explain this later on
   keywords = [],   # Keywords that define your package best
   install_requires=[
       {requirements}
@@ -477,7 +477,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]))
 
 
-# In[51]:
+# In[60]:
 
 
 package_files['setup.cfg'] = r"""# Inside of setup.cfg
@@ -486,7 +486,7 @@ description-file = README.md
 """
 
 
-# In[52]:
+# In[61]:
 
 
 package_files['LICENSE.txt'] = r"""MIT License
@@ -508,25 +508,25 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[53]:
+# In[62]:
 
 
 package_files['README.md'] = ""
 
 
-# In[54]:
+# In[63]:
 
 
 get_ipython().system(' jupyter nbconvert --to script lx.ipynb')
 
 
-# In[55]:
+# In[64]:
 
 
 package_files['lx/__init__.py'] = txtread("lx.py")
 
 
-# In[56]:
+# In[65]:
 
 
 def shell(cmd):
@@ -534,18 +534,20 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[57]:
+# In[66]:
 
 
 if isnotebook():
-    with tempfile.TemporaryDirectory() as d:
-        for key, value in package_files.items():
-            txtwrite(os.path.join(d, key), value)
-            
-        print("\n".join(fiFindByWildcard(os.path.join(d, '**/*'))))
-        
-        #print(shell("cd {d} && git status && git config user.name 'lx' && git config user.email 'lx' && git commit -a -m 'Add' && git log && git push && python setup.py sdist && twine upload dist/* --verbose".format(d=d)))
-        print(shell("cd {d} && python3 setup.py sdist && twine upload dist/* --verbose".format(d=d)))
+    #with tempfile.TemporaryDirectory() as d:
+    d = "/tmp/asdf9e2"
+    os.makedirs(d)
+    for key, value in package_files.items():
+        txtwrite(os.path.join(d, key), value)
+
+    print("\n".join(fiFindByWildcard(os.path.join(d, '**/*'))))
+
+    #print(shell("cd {d} && git status && git config user.name 'lx' && git config user.email 'lx' && git commit -a -m 'Add' && git log && git push && python setup.py sdist && twine upload dist/* --verbose".format(d=d)))
+    print(shell("cd {d} && python3 setup.py sdist && twine upload dist/* --verbose".format(d=d)))
 
 
 # In[ ]:
